from itsimodels.core.base_models import BaseModel
from itsimodels.core.fields import StringField


class GlassTableIcon(BaseModel):
    key = StringField(required=True, alias='_key')

    category = StringField()

    data = StringField(alias='dataURI')

    default_width = StringField()

    default_height = StringField()

    svg_path = StringField()

    title = StringField()



from itsimodels.core.fields import StringField
from itsimodels.core.base_models import DynamicModel


class CorrelationSearch(DynamicModel):
    key = StringField(required=True)

    name = StringField(required=True)



import setuptools

from itsimodels import __version__


setuptools.setup(
    name='itsimodels',
    version=__version__,
    author='Splunk, Inc.',
    description='Model Definitions for Splunk IT Service Intelligence',
    url='https://github.com/splunk/itsi-models',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=2.7',
)
